@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.104';
+our $VERSION = '0.105';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ Tickit::Widget::SparkLine - minimal graph implementation for L<Tickit>
 
 =head1 VERSION
 
-Version 0.104
+version 0.105
 
 =head1 SYNOPSIS
 
@@ -45,6 +45,7 @@ use Scalar::Util qw(reftype);
 use List::Util qw(max sum min);
 use Tickit::Utils qw(textwidth);
 use Tickit::Style;
+use constant WIDGET_PEN_FROM_STYLE => 1;
 
 BEGIN {
 	style_definition base =>
@@ -381,4 +382,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2011-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2011-2015. Licensed under the same terms as Perl itself.
